@@ -9,15 +9,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
- 'BINLIBDEST': '/usr/local/lib/python3.6',
- 'BLDLIBRARY': '-L. -lpython3.6m',
- 'BLDSHARED': 'cc -shared -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib '
-              '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector',
+ 'BINLIBDEST': '/usr/local/lib/python3.7',
+ 'BLDLIBRARY': '-L. -lpython3.7m',
+ 'BLDSHARED': 'cc -pthread -shared -L/usr/local/lib -Wl,-rpath,/usr/local/lib '
+              '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'i386-portbld-freebsd11.2',
  'BYTESTR_DEPS': '\\',
- 'CC': 'cc',
+ 'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
            '-pipe  -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all '
@@ -30,40 +30,42 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wstrict-prototypes',
+                            '-Wstrict-prototypes '
+                            '-Werror=implicit-function-declaration',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--without-ensurepip' '--without-pydebug' "
                 "'--enable-ipv6' '--with-system-ffi' '--with-pymalloc' "
-                "'--with-threads' '--prefix=/usr/local' '--localstatedir=/var' "
+                "'--prefix=/usr/local' '--localstatedir=/var' "
                 "'--mandir=/usr/local/man' '--infodir=/usr/local/share/info/' "
                 "'--build=i386-portbld-freebsd11.2' "
                 "'build_alias=i386-portbld-freebsd11.2' 'CC=cc' 'CFLAGS=-O2 "
                 '-pipe  -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all '
-                "-fno-strict-aliasing ' 'LDFLAGS= -lpthread -L/usr/local/lib "
+                "-fno-strict-aliasing ' 'LDFLAGS= -L/usr/local/lib "
                 '-Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now '
-                "-fstack-protector ' 'LIBS=' 'CPPFLAGS=-I/usr/local/include' "
-                "'CPP=cpp' 'PKG_CONFIG=pkgconf'",
+                "-fstack-protector-all ' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/local/include' 'CPP=cpp' "
+                "'PKG_CONFIG=pkgconf'",
  'CONFINCLUDEDIR': '/usr/local/include',
- 'CONFINCLUDEPY': '/usr/local/include/python3.6m',
- 'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/usr/obj/usr/ports/lang/python36/work/Python-3.6.8/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/usr/ports/lang/python36/work/Python-3.6.8/lcov-report',
+ 'CONFINCLUDEPY': '/usr/local/include/python3.7m',
+ 'COREPYTHONPATH': '',
+ 'COVERAGE_INFO': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
- 'CXX': 'c++',
- 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.6 '
-             '/usr/local/lib/python3.6/lib-dynload',
- 'DESTLIB': '/usr/local/lib/python3.6',
+ 'CXX': 'c++ -pthread',
+ 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.7 '
+             '/usr/local/lib/python3.7/lib-dynload',
+ 'DESTLIB': '/usr/local/lib/python3.7',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/local/lib/python3.6/lib-dynload',
+ 'DESTSHARED': '/usr/local/lib/python3.7/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DISABLED_EXTENSIONS': '_sqlite3 _tkinter _gdbm nis',
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+ 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+ 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
               'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
@@ -79,7 +81,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
@@ -125,6 +126,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
  'HAVE_CRYPT_H': 0,
+ 'HAVE_CRYPT_R': 0,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 1,
  'HAVE_CURSES_FILTER': 1,
@@ -146,6 +148,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
  'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
  'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
@@ -272,6 +275,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LINUX_VM_SOCKETS_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -280,7 +284,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -306,12 +309,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_POSIX_SPAWN': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PREADV': 1,
+ 'HAVE_PREADV2': 0,
  'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
+ 'HAVE_PTHREAD_GETCPUCLOCKID': 1,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
@@ -319,13 +325,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_PWRITEV': 1,
+ 'HAVE_PWRITEV2': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
@@ -340,7 +347,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SCHED_SETAFFINITY': 0,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
- 'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -366,6 +372,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGINFO_T_SI_BAND': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
  'HAVE_SIGPENDING': 1,
@@ -467,6 +474,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UUID_CREATE': 1,
+ 'HAVE_UUID_ENC_BE': 1,
+ 'HAVE_UUID_GENERATE_TIME_SAFE': 0,
+ 'HAVE_UUID_H': 1,
+ 'HAVE_UUID_UUID_H': 0,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -478,47 +490,48 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
+ 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'i386-portbld-freebsd11.2',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
-                   '/usr/local/include/python3.6m '
-                   '/usr/local/include/python3.6m',
+                   '/usr/local/include/python3.7m '
+                   '/usr/local/include/python3.7m',
  'INCLUDEDIR': '/usr/local/include',
- 'INCLUDEPY': '/usr/local/include/python3.6m',
+ 'INCLUDEPY': '/usr/local/include/python3.7m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': 'install  -m 0644',
  'INSTALL_PROGRAM': 'install  -s -m 555',
  'INSTALL_SCRIPT': 'install  -m 555',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.6m.so.1.0',
+ 'INSTSONAME': 'libpython3.7m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'c++ -shared',
- 'LDFLAGS': '-lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie '
-            '-Wl,-z,relro -Wl,-z,now -fstack-protector',
+ 'LDCXXSHARED': 'c++ -pthread -shared',
+ 'LDFLAGS': '-L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro '
+            '-Wl,-z,now -fstack-protector-all',
  'LDFLAGS_NODIST': '',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.6m.so',
+ 'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -shared -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib '
-             '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector',
- 'LDVERSION': '3.6m',
+ 'LDSHARED': 'cc -pthread -shared -L/usr/local/lib -Wl,-rpath,/usr/local/lib '
+             '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all',
+ 'LDVERSION': '3.7m',
  'LIBC': '',
- 'LIBDEST': '/usr/local/lib/python3.6',
+ 'LIBDEST': '/usr/local/lib/python3.7',
  'LIBDIR': '/usr/local/lib',
  'LIBFFI_INCLUDEDIR': '/usr/local/lib/libffi-3.2.1/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/local/libdata/pkgconfig',
- 'LIBPL': '/usr/local/lib/python3.6/config-3.6m',
- 'LIBRARY': 'libpython3.6m.a',
+ 'LIBPL': '/usr/local/lib/python3.7/config-3.7m',
+ 'LIBRARY': 'libpython3.7m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-ldl  -lutil',
+ 'LIBS': '-lcrypt -ldl  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'cc',
+ 'LINKCC': 'cc -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
@@ -528,39 +541,43 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'freebsd11',
- 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/local/lib/python3.6',
+ 'MACHDESTLIB': '/usr/local/lib/python3.7',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'cc',
+ 'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/local/man',
  'MKDIR_P': '/bin/mkdir -p',
+ 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
+                   '_operator  _collections  _abc  itertools  atexit  _signal  '
+                   '_stat  time  _thread  _locale  _io  zipimport  '
+                   'faulthandler  _tracemalloc  _symtable  xxsubtype',
+ 'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools '
-             '_operator _collections itertools atexit _signal _stat time '
-             '_locale _io zipimport faulthandler _tracemalloc _symtable '
-             'xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  '
-            'Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  '
-            'Modules/_codecsmodule.o  Modules/_weakref.o  '
-            'Modules/_functoolsmodule.o  Modules/_operator.o  '
-            'Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  '
+ 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/_abc.o  Modules/itertoolsmodule.o  '
             'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
-            'Modules/timemodule.o  Modules/_localemodule.o  '
-            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
-            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
-            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/timemodule.o  Modules/_threadmodule.o  '
+            'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
+            'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
+            'Modules/textio.o Modules/stringio.o  Modules/zipimport.o  '
+            'Modules/faulthandler.o  Modules/_tracemalloc.o '
+            'Modules/hashtable.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MULTIARCH_CPPFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
+ 'OPENSSL_INCLUDES': '-I/usr/local/include',
+ 'OPENSSL_LDFLAGS': '-L/usr/local/lib',
+ 'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -576,10 +593,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '',
  'PGO_PROF_USE_FLAG': '',
- 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': 'libpython3.so',
@@ -589,30 +606,52 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':',
+ 'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
+                             '-Wunreachable-code -DNDEBUG -O2 -pipe  '
+                             '-DHARDENEDBSD -fPIE -fPIC -fstack-protector-all '
+                             '-fno-strict-aliasing -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
+                             '-Werror=implicit-function-declaration -I. '
+                             '-I./Include -I/usr/local/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
               '-O2 -pipe  -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all '
               '-fno-strict-aliasing',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes',
+                     '-Wstrict-prototypes '
+                     '-Werror=implicit-function-declaration',
+ 'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
                    '-DNDEBUG -O2 -pipe  -DHARDENEDBSD -fPIE -fPIC '
                    '-fstack-protector-all -fno-strict-aliasing -std=c99 '
                    '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes -I. '
-                   '-I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie '
-                    '-Wl,-z,relro -Wl,-z,now -fstack-protector',
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -I. -I./Include '
+                   '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie '
+                    '-Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie '
-               '-Wl,-z,relro -Wl,-z,now -fstack-protector',
+ 'PY_LDFLAGS': '-L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro '
+               '-Wl,-z,now -fstack-protector-all',
  'PY_LDFLAGS_NODIST': '',
+ 'PY_SSL_DEFAULT_CIPHERS': 1,
+ 'PY_SSL_DEFAULT_CIPHER_STRING': 0,
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                        '-DNDEBUG -O2 -pipe  -DHARDENEDBSD -fPIE -fPIC '
+                        '-fstack-protector-all -fno-strict-aliasing -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+                        '-Werror=implicit-function-declaration -I. -I./Include '
+                        '-I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -620,12 +659,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python36/work/Python-3.6.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.4',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
- 'SGI_ABI': '',
+ 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-ldl  -lutil',
+ 'SHLIBS': '-lcrypt -ldl  -lutil',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -638,6 +677,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
+ 'SIZEOF_PTHREAD_KEY_T': 4,
  'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 4,
@@ -646,8 +686,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36m',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
+ 'SOABI': 'cpython-37m',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -661,13 +701,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python36/work/Python-3.6.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.4 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python36/work/Python-3.6.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.4 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
- 'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
@@ -675,9 +714,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'USE_INLINE': 1,
- 'VERSION': '3.6',
- 'WANT_SIGFPE_HANDLER': 0,
+ 'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -685,12 +722,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
- 'WITH_THREAD': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/usr/ports/lang/python36/work/Python-3.6.8',
- 'abs_srcdir': '/usr/obj/usr/ports/lang/python36/work/Python-3.6.8',
+ 'abs_builddir': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4',
+ 'abs_srcdir': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
