@@ -1,31 +1,30 @@
 <?php
-/**
-*    Copyright (C) 2015 Deciso B.V.
-*
-*    All rights reserved.
-*
-*    Redistribution and use in source and binary forms, with or without
-*    modification, are permitted provided that the following conditions are met:
-*
-*    1. Redistributions of source code must retain the above copyright notice,
-*       this list of conditions and the following disclaimer.
-*
-*    2. Redistributions in binary form must reproduce the above copyright
-*       notice, this list of conditions and the following disclaimer in the
-*       documentation and/or other materials provided with the distribution.
-*
-*    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
-*    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
-*    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
-*    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
-*    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-*    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-*    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-*    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-*    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-*    POSSIBILITY OF SUCH DAMAGE.
-*
-*/
+
+/*
+ * Copyright (C) 2015 Deciso B.V.
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
+ * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ */
 
 namespace OPNsense\Base;
 
@@ -110,16 +109,18 @@ abstract class BaseModel
 
     /**
      * fetch reflection class (cached by field type)
-     * @param $classname classname to construct
-     * @return array
-     * @throws ModelException
+     * @param string $classname classname to construct
+     * @return BaseField type class
+     * @throws ModelException when unable to parse field type
+     * @throws \ReflectionException when unable to create class
      */
     private function getNewField($classname)
     {
         if (self::$internalCacheReflectionClasses === null) {
             self::$internalCacheReflectionClasses = array();
         }
-        if (!isset(self::$internalCacheReflectionClasses[$classname])) {
+        $classname_idx = str_replace("\\", "_", $classname);
+        if (!isset(self::$internalCacheReflectionClasses[$classname_idx])) {
             $is_derived_from_basefield = false;
             if (class_exists($classname)) {
                 $field_rfcls = new \ReflectionClass($classname);
@@ -136,9 +137,9 @@ abstract class BaseModel
                 // class found, but of wrong type. raise an exception.
                 throw new ModelException("class ".$field_rfcls->name." of wrong type in model definition");
             }
-            self::$internalCacheReflectionClasses[$classname] = $field_rfcls;
+            self::$internalCacheReflectionClasses[$classname_idx] = $field_rfcls;
         }
-        return self::$internalCacheReflectionClasses[$classname];
+        return self::$internalCacheReflectionClasses[$classname_idx];
     }
 
     /**
@@ -147,6 +148,7 @@ abstract class BaseModel
      * @param SimpleXMLElement $config_data (current) config data
      * @param BaseField $internal_data output structure using FieldTypes,rootnode is internalData
      * @throws ModelException parse error
+     * @throws \ReflectionException
      */
     private function parseXml(&$xml, &$config_data, &$internal_data)
     {
@@ -165,7 +167,22 @@ abstract class BaseModel
             $xmlNodeType = $xmlNode->attributes()["type"];
             if (!empty($xmlNodeType)) {
                 // construct field type object
-                $field_rfcls = $this->getNewField("OPNsense\\Base\\FieldTypes\\".$xmlNodeType);
+                if (strpos($xmlNodeType, "\\") !== false) {
+                    // application specific field type contains path separator
+                    if (strpos($xmlNodeType, ".\\") === 0) {
+                        // use current namespace (.\Class)
+                        $namespace = explode("\\", get_class($this));
+                        array_pop($namespace);
+                        $namespace = implode("\\", $namespace);
+                        $classname = str_replace(".\\", $namespace."\\FieldTypes\\", (string)$xmlNodeType);
+                    } else {
+                        $classname = (string)$xmlNodeType;
+                    }
+                    $field_rfcls = $this->getNewField($classname);
+                } else {
+                    // standard field type
+                    $field_rfcls = $this->getNewField("OPNsense\\Base\\FieldTypes\\".$xmlNodeType);
+                }
             } else {
                 // no type defined, so this must be a standard container (without content)
                 $field_rfcls = $this->getNewField('OPNsense\Base\FieldTypes\ContainerField');
@@ -206,7 +223,7 @@ abstract class BaseModel
 
                 if ($fieldObject instanceof ArrayField) {
                     // handle Array types, recurring items
-                    if ($config_section_data != null) {
+                    if ($config_section_data != null && !empty((string)$config_section_data)) {
                         foreach ($config_section_data as $conf_section) {
                             // Array items are identified by a UUID, read from attribute or create a new one
                             if (isset($conf_section->attributes()->uuid)) {
@@ -244,8 +261,9 @@ abstract class BaseModel
     }
 
     /**
-     * Construct new model type, using it's own xml template
+     * Construct new model type, using its own xml template
      * @throws ModelException if the model xml is not found or invalid
+     * @throws \ReflectionException
      */
     public function __construct()
     {
@@ -343,12 +361,22 @@ abstract class BaseModel
      * structured setter for model
      * @param array|$data named array
      * @return array
+     * @throws \Exception
      */
     public function setNodes($data)
     {
         return $this->internalData->setNodes($data);
     }
 
+    /**
+     * iterate (non virtual) child nodes
+     * @return mixed
+     */
+    public function iterateItems()
+    {
+        return $this->internalData->iterateItems();
+    }
+
     /**
      * validate full model using all fields and data in a single (1 deep) array
      * @param bool $validateFullModel validate full model or only changed fields
@@ -393,7 +421,7 @@ abstract class BaseModel
     {
         $result = array();
         $valMsgs = $this->performValidation();
-        foreach ($valMsgs as $field => $msg) {
+        foreach ($valMsgs as $msg) {
             // replace absolute path to attribute for relative one at uuid.
             if ($sourceref != null) {
                 $fieldnm = str_replace($sourceref, $targetref, $msg->getField());
@@ -561,11 +589,14 @@ abstract class BaseModel
      * The BaseModelMigration class should be named with the corresponding version
      * prefixed with an M and . replaced by _ for example : M1_0_1 equals version 1.0.1
      *
+     * @return bool status (true-->success, false-->failed)
+     * @throws \ReflectionException
      */
     public function runMigrations()
     {
         if (version_compare($this->internal_current_model_version, $this->internal_model_version, '<')) {
             $upgradePerfomed = false;
+            $migObjects = array();
             $logger = new Syslog("config", array('option' => LOG_PID, 'facility' => LOG_LOCAL4));
             $class_info = new \ReflectionClass($this);
             // fetch version migrations
@@ -597,6 +628,7 @@ abstract class BaseModel
                         $migobj = $mig_class->newInstance();
                         try {
                             $migobj->run($this);
+                            $migObjects[] = $migobj;
                             $upgradePerfomed = true;
                         } catch (\Exception $e) {
                             $logger->error("failed migrating from version " .
@@ -614,10 +646,16 @@ abstract class BaseModel
             if ($upgradePerfomed) {
                 try {
                     $this->serializeToConfig();
+                    foreach ($migObjects as $migobj) {
+                        $migobj->post($this);
+                    }
                 } catch (\Exception $e) {
                     $logger->error("Model ".$class_info->getName() ." can't be saved, skip ( " .$e . " )");
+                    return false;
                 }
             }
+
+            return true;
         }
     }
 
