@@ -23,6 +23,31 @@ function view_fetch_themed_filename($url, $theme)
     return $url; // not found, return source
 }
 
+/**
+ * check if file exists, wrapper around file_exists() so services.php can define other implementation for local testing
+ * @param string $filename to check
+ * @return boolean
+ */
+function view_file_exists($filename)
+{
+    return file_exists($filename);
+}
+
+/**
+ * return appended version string with a hash for proper caching for currently installed version
+ * @param string $url to make cache-safe
+ * @return string
+ */
+function view_cache_safe($url)
+{
+    $info = stat('/usr/local/opnsense/www/index.php');
+    if (!empty($info['mtime'])) {
+        return "{$url}?v=" . substr(md5($info['mtime']), 0, 16);
+    }
+
+    return $url;
+}
+
 try {
     /**
      * Read the configuration
