@@ -1,32 +1,32 @@
 <?php
 
 /*
-    Copyright (C) 2014-2015 Deciso B.V.
-    Copyright (C) 2009 Scott Ullrich <sullrich@gmail.com>
-    Copyright (C) 2003-2005 Manuel Kasper <mk@neon1.net>
-    All rights reserved.
-
-    Redistribution and use in source and binary forms, with or without
-    modification, are permitted provided that the following conditions are met:
-
-    1. Redistributions of source code must retain the above copyright notice,
-       this list of conditions and the following disclaimer.
-
-    2. Redistributions in binary form must reproduce the above copyright
-       notice, this list of conditions and the following disclaimer in the
-       documentation and/or other materials provided with the distribution.
-
-    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
-    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
-    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
-    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
-    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-    POSSIBILITY OF SUCH DAMAGE.
-*/
+ * Copyright (C) 2014-2015 Deciso B.V.
+ * Copyright (C) 2009 Scott Ullrich <sullrich@gmail.com>
+ * Copyright (C) 2003-2005 Manuel Kasper <mk@neon1.net>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
+ * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ */
 
 require_once("guiconfig.inc");
 require_once("system.inc");
@@ -36,10 +36,12 @@ require_once("interfaces.inc");
 if ($_SERVER['REQUEST_METHOD'] === 'POST') {
     if (!empty($_POST['if']) && !empty($_POST['submit'])) {
         $interface = $_POST['if'];
-        if (!empty($_POST['status']) && $_POST['status'] == 'up') {
+        if ($_POST['submit'] == 'remote') {
+            configdp_run('interface reconfigure', array($interface));
+        } elseif (!empty($_POST['status']) && $_POST['status'] == 'up') {
             interface_bring_down($interface);
         } else {
-            interface_configure($interface);
+            interface_configure(false, $interface, true);
         }
         header(url_safe('Location: /status_interfaces.php'));
         exit;
@@ -64,16 +66,16 @@ include("head.inc");
         <div class="row">
           <section class="col-xs-12">
 <?php
-            $mac_man = json_decode(configd_run("interface list macdb json"), true);
-            $pfctl_counters = json_decode(configd_run("filter list counters json"), true);
-            $vmstat_interupts = json_decode(configd_run("system list interrupts json"), true);
+            $mac_man = json_decode(configd_run('interface list macdb json'), true);
+            $pfctl_counters = json_decode(configd_run('filter list counters json'), true);
+            $vmstat_interupts = json_decode(configd_run('system list interrupts json'), true);
             $ifsinfo = get_interfaces_info();
-            foreach (get_configured_interface_with_descr(false, true) as $ifdescr => $ifname):
+            foreach (legacy_config_get_interfaces(array('virtual' => false)) as $ifdescr => $ifcfg):
               $ifinfo = $ifsinfo[$ifdescr];
               $ifpfcounters = $pfctl_counters[$ifinfo['if']];
               legacy_html_escape_form_data($ifinfo);
               $ifdescr = htmlspecialchars($ifdescr);
-              $ifname = htmlspecialchars($ifname);
+              $ifname = htmlspecialchars($ifcfg['descr']);
 ?>
               <div class="tab-content content-box col-xs-12 __mb">
                 <div class="table-responsive">
@@ -114,7 +116,8 @@ include("head.inc");
                           <input type="hidden" name="if" value="<?= $ifdescr ?>" />
                           <input type="hidden" name="status" value="<?= $ifinfo['dhcplink'] ?>" />
                           <?= $ifinfo['dhcplink'] ?>&nbsp;&nbsp;
-                          <input type="submit" name="submit" class="btn btn-primary btn-xs" value="<?= $ifinfo['dhcplink'] == "up" ? gettext("Release") : gettext("Renew"); ?>" />
+                          <button type="submit" name="submit" class="btn btn-primary btn-xs" value="remote"><?= gettext('Reload') ?></button>
+                          <button type="submit" name="submit" class="btn btn-xs" value="local"><?= $ifinfo['dhcplink'] == "up" ? gettext("Release") : gettext("Renew") ?></button>
                         </form>
                       </td>
                     </tr>
@@ -128,7 +131,8 @@ include("head.inc");
                           <input type="hidden" name="if" value="<?= $ifdescr ?>" />
                           <input type="hidden" name="status" value="<?= $ifinfo['dhcp6link'] ?>" />
                           <?= $ifinfo['dhcp6link'] ?>&nbsp;&nbsp;
-                          <input type="submit" name="submit" class="btn btn-primary btn-xs" value="<?= $ifinfo['dhcp6link'] == "up" ? gettext("Release") : gettext("Renew") ?>" />
+                          <button type="submit" name="submit" class="btn btn-primary btn-xs" value="remote"><?= gettext('Reload') ?></button>
+                          <button type="submit" name="submit" class="btn btn-xs" value="local"><?= $ifinfo['dhcp6link'] == "up" ? gettext("Release") : gettext("Renew") ?></button>
                         </form>
                       </td>
                     </tr>
@@ -142,7 +146,8 @@ include("head.inc");
                           <input type="hidden" name="if" value="<?= $ifdescr ?>" />
                           <input type="hidden" name="status" value="<?= $ifinfo['pppoelink'] ?>" />
                           <?= $ifinfo['pppoelink'] ?>&nbsp;&nbsp;
-                          <input type="submit" name="submit" class="btn btn-primary btn-xs" value="<?= $ifinfo['pppoelink'] == "up" ? gettext("Disconnect") : gettext("Connect") ?>" />
+                          <button type="submit" name="submit" class="btn btn-primary btn-xs" value="remote"><?= gettext('Reload') ?></button>
+                          <button type="submit" name="submit" class="btn btn-xs" value="local"><?= $ifinfo['pppoelink'] == "up" ? gettext("Disconnect") : gettext("Connect") ?></button>
                         </form>
                       </td>
                     </tr>
@@ -156,7 +161,8 @@ include("head.inc");
                           <input type="hidden" name="if" value="<?= $ifdescr ?>" />
                           <input type="hidden" name="status" value="<?= $ifinfo['pptplink'] ?>" />
                           <?= $ifinfo['pptplink'] ?>&nbsp;&nbsp;
-                          <input type="submit" name="submit" class="btn btn-primary btn-xs" value="<?= $ifinfo['pptplink'] == "up" ? gettext("Disconnect") : gettext("Connect") ?>" />
+                          <button type="submit" name="submit" class="btn btn-primary btn-xs" value="remote"><?= gettext('Reload') ?></button>
+                          <button type="submit" name="submit" class="btn btn-xs" value="local"><?= $ifinfo['pptplink'] == "up" ? gettext("Disconnect") : gettext("Connect") ?></button>
                         </form>
                       </td>
                     </tr>
@@ -170,7 +176,8 @@ include("head.inc");
                           <input type="hidden" name="if" value="<?= $ifdescr ?>" />
                           <input type="hidden" name="status" value="<?= $ifinfo['l2tplink'] ?>" />
                           <?=$ifinfo['l2tplink'];?>&nbsp;&nbsp;
-                          <input type="submit" name="submit" class="btn btn-primary btn-xs" value="<?= $ifinfo['l2tplink'] == "up" ? gettext("Disconnect") : gettext("Connect") ?>" />
+                          <button type="submit" name="submit" class="btn btn-primary btn-xs" value="remote"><?= gettext('Reload') ?></button>
+                          <button type="submit" name="submit" class="btn btn-xs" value="local"><?= $ifinfo['l2tplink'] == "up" ? gettext("Disconnect") : gettext("Connect") ?></button>
                         </form>
                       </td>
                     </tr>
@@ -184,13 +191,12 @@ include("head.inc");
                           <input type="hidden" name="if" value="<?= $ifdescr ?>" />
                           <input type="hidden" name="status" value="<?= $ifinfo['ppplink'] ?>" />
                           <?= $ifinfo['pppinfo'] ?>
+                          <button type="submit" name="submit" class="btn btn-primary btn-xs" value="remote"><?= gettext('Reload') ?></button>
                           <?php if ($ifinfo['ppplink'] == "up"): ?>
-                            <input type="submit" name="submit" class="btn btn-primary btn-xs" value="<?= gettext("Disconnect") ?>" />
-                          <?php else: ?>
-                            <?php if (!$ifinfo['nodevice']): ?>
-                              <input type="submit" name="submit" class="btn btn-primary btn-xs" value="<?= gettext("Connect") ?>" />
-                            <?php endif; ?>
-                          <?php endif; ?>
+                            <button type="submit" name="submit" class="btn btn-xs" value="local"><?= gettext("Disconnect") ?></button>
+                          <?php elseif (!$ifinfo['nodevice']): ?>
+                            <button type="submit" name="submit" class="btn btn-xs" value="local"><?= gettext("Connect") ?></button>
+                          <?php endif ?>
                         </form>
                       </td>
                     </tr>
@@ -273,19 +279,32 @@ include("head.inc");
                     </tr>
 <?php
                   endif;
+                  if ($ifinfo['mtu']): ?>
+                  <tr>
+                    <td><?=gettext("MTU");?></td>
+                    <td>
+                      <?=$ifinfo['mtu'];?>
+                    </td>
+                  </tr>
+<?php
+                endif;
                 if ($ifinfo['status'] != "down"):
                   if ($ifinfo['dhcplink'] != "down" && $ifinfo['pppoelink'] != "down" && $ifinfo['pptplink'] != "down"):
-                    if ($ifinfo['ipaddr']):?>
+                    if (!empty($ifinfo['ipaddr'])):?>
                     <tr>
                       <td><?= gettext("IPv4 address") ?></td>
-                      <td><?= $ifinfo['ipaddr'] ?></td>
-                    </tr>
+                      <td>
+                        <?=$ifinfo['ipaddr'];?> /  <?=$ifinfo['subnet'];?>
 <?php
-                    endif;
-                    if (!empty($ifinfo['subnet'])):?>
-                    <tr>
-                      <td><?= gettext("Subnet mask IPv4") ?></td>
-                      <td><?= $ifinfo['subnet'] ?></td>
+                        foreach($ifinfo['ipv4'] as $ipv4):
+                            if ($ipv4['ipaddr'] != $ifinfo['ipaddr']):?>
+                            <br/>
+                            <i class="fa fa-plus-square-o" aria-hidden="true"></i>
+                            <?=$ipv4['ipaddr'];?> / <?=$ipv4['subnetbits'];?> <?= !empty($ipv4['vhid']) ? 'vhid ' . $ipv4['vhid'] : "" ;?>
+<?php
+                            endif;
+                        endforeach;?>
+                      </td>
                     </tr>
 <?php
                     endif;
@@ -296,24 +315,29 @@ include("head.inc");
                     </tr>
 <?php
                     endif;
-                    if (!empty($ifinfo['linklocal'])): ?>
+                    $llitem = !empty($ifinfo['ipv6']) ? end($ifinfo['ipv6']) : null;
+                    if (!empty($llitem['link-local'])): ?>
                     <tr>
                       <td><?= gettext("IPv6 Link Local") ?></td>
-                      <td><?= $ifinfo['linklocal'] ?></td>
+                      <td><?= $llitem['ipaddr'];?> / <?= $llitem['subnetbits'];?>
                     </tr>
 <?php
                     endif;
                     if (!empty($ifinfo['ipaddrv6'])): ?>
                     <tr>
                       <td><?= gettext("IPv6 address") ?></td>
-                      <td><?= $ifinfo['ipaddrv6'] ?></td>
-                    </tr>
+                      <td>
+                        <?= $ifinfo['ipaddrv6'] ?> / <?= $ifinfo['subnetv6'] ?>
 <?php
-                    endif;
-                    if (!empty($ifinfo['subnetv6'])): ?>
-                    <tr>
-                      <td><?= gettext("Subnet mask IPv6") ?></td>
-                      <td><?= $ifinfo['subnetv6'] ?></td>
+                        foreach($ifinfo['ipv6'] as $ipv6):
+                            if ($ipv6['ipaddr'] != $ifinfo['ipaddrv6'] && empty($ipv6['link-local'])):?>
+                            <br/>
+                            <i class="fa fa-plus-square-o" aria-hidden="true"></i>
+                            <?=$ipv6['ipaddr'];?> / <?=$ipv6['subnetbits'];?> <?= !empty($ipv6['vhid']) ? 'vhid ' . $ipv6['vhid'] : "" ;?>
+<?php
+                            endif;
+                        endforeach;?>
+                      </td>
                     </tr>
 <?php
                     endif;
@@ -324,14 +348,13 @@ include("head.inc");
                     </tr>
 <?php
                     endif;
-                    if ($ifdescr == 'wan' && file_exists('/etc/resolv.conf')): ?>
+                    $dnsall = get_nameservers($ifdescr);
+                    if (count($dnsall)): ?>
                     <tr>
                       <td><?= gettext("DNS servers") ?></td>
                       <td>
 <?php
-                        foreach(get_dns_servers() as $dns):
-                          echo "{$dns}<br />";
-                        endforeach; ?>
+                          echo implode('<br />', $dnsall); ?>
                       </td>
                     </tr>
 <?php
@@ -445,7 +468,7 @@ include("head.inc");
                     <tr>
                       <td><?= gettext("Interrupts") ?></td>
                       <td>
-                        <table class="table">
+                        <table class="table table-condensed">
                           <thead>
                             <tr>
                               <th><?=gettext("irq");?></th>
@@ -469,6 +492,37 @@ include("head.inc");
                     </tr>
 <?php
                   endif; ?>
+<?php
+                  if (!empty($ifinfo['carp'])):?>
+                  <tr>
+                      <td><?=gettext("CARP");?></td>
+                      <td>
+                          <table class="table table-condensed">
+                            <thead>
+                              <tr>
+                                <th><?=gettext("status");?></th>
+                                <th><?=gettext("vhid");?></th>
+                                <th><?=gettext("advbase");?></th>
+                                <th><?=gettext("advskew");?></th>
+                              </tr>
+                            </thead>
+                            <tbody>
+<?php
+                            foreach($ifinfo['carp'] as $carpitem):?>
+                                <tr>
+                                  <td><?=$carpitem['status'];?></td>
+                                  <td><?=$carpitem['vhid'];?></td>
+                                  <td><?=$carpitem['advbase'];?></td>
+                                  <td><?=$carpitem['advskew'];?></td>
+                                </tr>
+<?php
+                            endforeach;?>
+                            </tbody>
+                          </table>
+                      </td>
+                  </tr>
+<?php
+                  endif;?>
                   </tbody>
                 </table>
               </div>
